@@ -1,11 +1,29 @@
 vov_params <- function() {
   c(
     '@param ui A UI element',
-    '@param duration Duration of animation; Enter word: "fast" = 800 milliseconds, "faster" = 500 milliseconds, "fastest" = 300 milliseconds, "slow" = 2 seconds, "slower" = 3 seconds, "slowest" = 4 seconds',
-    '@param delay Delay in seconds before animation starts; Enter value: 0 - 5'
+    '@param duration Duration of animation',
+    '@param delay Delay in seconds before animation starts',
+    '@param steps Animation steps',
+    '@param iteration Iteration of animation',
+    '@details
+      \\itemize{
+        \\item Duration expects one of: "fast" = 800 milliseconds, "faster" = 500 milliseconds, "fastest" = 300 milliseconds, "slow" = 2 seconds, "slower" = 3 seconds, "slowest" = 4 seconds,
+        \\item Delay expects one of: 0, 1, 2, 3, 4, 5, no delay if left NULL
+        \\item Steps expects one of: 10, 20, 30, 40, 50, no steps if left NULL
+        \\item Iteration expects one of: 1, 2, 3, 4, 5, infinite, no iteration if left NULL
+      }'
   )
 }
 
+# vov_details <- function() {
+#   '@details
+#   \\itemize{
+#     \\item Duration expects one of: "fast" = 800 milliseconds, "faster" = 500 milliseconds, "fastest" = 300 milliseconds, "slow" = 2 seconds, "slower" = 3 seconds, "slowest" = 4 seconds,
+#     \\item Delay expects one of: 1, 2, 3, 4, 5, no delay if left NULL
+#     \\item Steps expects one of: 10, 20, 30, 40, 50, no steps if left NULL
+#     \\item Iteration expects one of: 1, 2, 3, 4, 5, infinite, no iteration if left NULL
+#   }'
+# }
 #' Use the vov package
 #'
 #' @description Enables vov by including the CSS file necessary for the
@@ -69,8 +87,8 @@ run_demo <- function() {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_in_bottom_left <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-in-bottom-left", duration, delay)
+fade_in_bottom_left <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-in-bottom-left", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -97,8 +115,8 @@ fade_in_bottom_left <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_in_bottom_right <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-in-bottom-right", duration, delay)
+fade_in_bottom_right <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-in-bottom-right", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -125,8 +143,8 @@ fade_in_bottom_right <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_in_down <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-in-down", duration, delay)
+fade_in_down <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-in-down", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -153,8 +171,8 @@ fade_in_down <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_in_left <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-in-left", duration, delay)
+fade_in_left <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-in-left", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -181,8 +199,8 @@ fade_in_left <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_in_right <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-in-right", duration, delay)
+fade_in_right <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-in-right", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -209,8 +227,8 @@ fade_in_right <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_in_top_left <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-in-top-left", duration, delay)
+fade_in_top_left <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-in-top-left", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -237,8 +255,8 @@ fade_in_top_left <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_in_top_right <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-in-top-right", duration, delay)
+fade_in_top_right <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-in-top-right", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -265,8 +283,8 @@ fade_in_top_right <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_in_up <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-in-up", duration, delay)
+fade_in_up <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-in-up", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -293,8 +311,8 @@ fade_in_up <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_in <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-in", duration, delay)
+fade_in <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-in", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -322,8 +340,8 @@ fade_in <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_out_bottom_left <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-out-bottom-left", duration, delay)
+fade_out_bottom_left <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-out-bottom-left", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -351,8 +369,8 @@ fade_out_bottom_left <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_out_bottom_right <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-out-bottom-right", duration, delay)
+fade_out_bottom_right <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-out-bottom-right", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -379,8 +397,8 @@ fade_out_bottom_right <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_out_down <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-out-down", duration, delay)
+fade_out_down <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-out-down", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -407,8 +425,8 @@ fade_out_down <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_out_left <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-out-left", duration, delay)
+fade_out_left <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-out-left", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -435,8 +453,8 @@ fade_out_left <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_out_right <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-out-right", duration, delay)
+fade_out_right <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-out-right", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -464,8 +482,8 @@ fade_out_right <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_out_top_left <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-out-top-left", duration, delay)
+fade_out_top_left <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-out-top-left", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -493,8 +511,8 @@ fade_out_top_left <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_out_top_right <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-out-top-right", duration, delay)
+fade_out_top_right <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-out-top-right", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -521,8 +539,8 @@ fade_out_top_right <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_out_up <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-out-up", duration, delay)
+fade_out_up <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-out-up", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -549,8 +567,8 @@ fade_out_up <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-fade_out <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("fade-out", duration, delay)
+fade_out <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("fade-out", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -577,8 +595,8 @@ fade_out <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-roll_in_left <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("roll-in-left", duration, delay)
+roll_in_left <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("roll-in-left", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -605,8 +623,8 @@ roll_in_left <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-roll_in_right <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("roll-in-right", duration, delay)
+roll_in_right <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("roll-in-right", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -633,8 +651,8 @@ roll_in_right <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-roll_out_left <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("roll-out-left", duration, delay)
+roll_out_left <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("roll-out-left", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -661,8 +679,8 @@ roll_out_left <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-roll_out_right <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("roll-out-right", duration, delay)
+roll_out_right <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("roll-out-right", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -689,8 +707,8 @@ roll_out_right <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-shake_vertical <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("shake-vertical", duration, delay)
+shake_vertical <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("shake-vertical", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -717,8 +735,64 @@ shake_vertical <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-shake_horizontal <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("shake-horizontal", duration, delay)
+shake_horizontal <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("shake-horizontal", duration, delay, steps, iteration)
+  htmltools::tagAppendAttributes(ui, class = x)
+}
+
+#' Shake diagonally
+#'
+#' @description Animation to shake a UI element diagonally.
+#'
+#' @eval vov_params()
+#'
+#' @examples
+#' if (interactive()) {
+#'   library(shiny)
+#'   library(vov)
+#'
+#'   ui <- fluidPage(
+#'     use_vov(),
+#'     shake_diagonally(
+#'       h1("Hello world!")
+#'     )
+#'   )
+#'
+#'   server <- function(input, output, session) {}
+#'
+#'   shinyApp(ui, server)
+#' }
+#' @export
+shake_diagonally <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("shake-diagonally", duration, delay, steps, iteration)
+  htmltools::tagAppendAttributes(ui, class = x)
+}
+
+#' Shake diagonally inverse
+#'
+#' @description Animation to shake a UI element diagonally.
+#'
+#' @eval vov_params()
+#'
+#' @examples
+#' if (interactive()) {
+#'   library(shiny)
+#'   library(vov)
+#'
+#'   ui <- fluidPage(
+#'     use_vov(),
+#'     shake_i_diagonally(
+#'       h1("Hello world!")
+#'     )
+#'   )
+#'
+#'   server <- function(input, output, session) {}
+#'
+#'   shinyApp(ui, server)
+#' }
+#' @export
+shake_i_diagonally <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("shake-i-diagonally", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -745,8 +819,8 @@ shake_horizontal <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-blur_in <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("blur-in", duration, delay)
+blur_in <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("blur-in", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -773,8 +847,8 @@ blur_in <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-blur_out <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("blur-out", duration, delay)
+blur_out <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("blur-out", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -801,8 +875,8 @@ blur_out <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-slide_in_down <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("slide-in-down", duration, delay)
+slide_in_down <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("slide-in-down", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -829,8 +903,8 @@ slide_in_down <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-slide_in_left <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("slide-in-left", duration, delay)
+slide_in_left <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("slide-in-left", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -857,8 +931,8 @@ slide_in_left <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-slide_in_right <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("slide-in-right", duration, delay)
+slide_in_right <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("slide-in-right", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -885,8 +959,8 @@ slide_in_right <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-slide_in_up <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("slide-in-up", duration, delay)
+slide_in_up <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("slide-in-up", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -913,8 +987,8 @@ slide_in_up <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-slide_out_down <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("slide-out-down", duration, delay)
+slide_out_down <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("slide-out-down", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -941,8 +1015,8 @@ slide_out_down <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-slide_out_left <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("slide-out-left", duration, delay)
+slide_out_left <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("slide-out-left", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -969,8 +1043,8 @@ slide_out_left <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-slide_out_right <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("slide-out-right", duration, delay)
+slide_out_right <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("slide-out-right", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -997,8 +1071,8 @@ slide_out_right <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-slide_out_up <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("slide-out-up", duration, delay)
+slide_out_up <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("slide-out-up", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -1025,8 +1099,8 @@ slide_out_up <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-throb <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("throb", duration, delay)
+throb <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("throb", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -1053,8 +1127,8 @@ throb <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-i_throb <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("i-throb", duration, delay)
+i_throb <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("i-throb", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -1081,8 +1155,8 @@ i_throb <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-swivel_horizontal <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("swivel-horizontal", duration, delay)
+swivel_horizontal <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("swivel-horizontal", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -1109,8 +1183,8 @@ swivel_horizontal <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-swivel_horizontal_double <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("swivel-horizontal-double", duration, delay)
+swivel_horizontal_double <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("swivel-horizontal-double", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -1137,8 +1211,8 @@ swivel_horizontal_double <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-swivel_vertical <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("swivel-vertical", duration, delay)
+swivel_vertical <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("swivel-vertical", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -1165,8 +1239,8 @@ swivel_vertical <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-swivel_vertical_double <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("swivel-vertical-double", duration, delay)
+swivel_vertical_double <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("swivel-vertical-double", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -1193,8 +1267,8 @@ swivel_vertical_double <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-wheel_in_left <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("wheel-in-left", duration, delay)
+wheel_in_left <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("wheel-in-left", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -1221,8 +1295,8 @@ wheel_in_left <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-wheel_in_right <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("wheel-in-right", duration, delay)
+wheel_in_right <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("wheel-in-right", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -1249,8 +1323,8 @@ wheel_in_right <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-wheel_out_left <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("wheel-out-left", duration, delay)
+wheel_out_left <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("wheel-out-left", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -1277,8 +1351,8 @@ wheel_out_left <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-wheel_out_right <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("wheel-out-right", duration, delay)
+wheel_out_right <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("wheel-out-right", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
@@ -1305,8 +1379,287 @@ wheel_out_right <- function(ui, duration = NULL, delay = NULL) {
 #'   shinyApp(ui, server)
 #' }
 #' @export
-flash <- function(ui, duration = NULL, delay = NULL) {
-  x <- parse_animation("flash", duration, delay)
+flash <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("flash", duration, delay, steps, iteration)
   htmltools::tagAppendAttributes(ui, class = x)
 }
 
+#' Zoom in down
+#'
+#' @description Animation to zoom a UI element down.
+#'
+#' @eval vov_params()
+#'
+#' @examples
+#' if (interactive()) {
+#'   library(shiny)
+#'   library(vov)
+#'
+#'   ui <- fluidPage(
+#'     use_vov(),
+#'     zoom_in_down(
+#'       h1("Hello world!")
+#'     )
+#'   )
+#'
+#'   server <- function(input, output, session) {}
+#'
+#'   shinyApp(ui, server)
+#' }
+#' @export
+zoom_in_down <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("zoom-in-down", duration, delay, steps, iteration)
+  htmltools::tagAppendAttributes(ui, class = x)
+}
+
+#' Zoom in left
+#'
+#' @description Animation to zoom a UI element left.
+#'
+#' @eval vov_params()
+#'
+#' @examples
+#' if (interactive()) {
+#'   library(shiny)
+#'   library(vov)
+#'
+#'   ui <- fluidPage(
+#'     use_vov(),
+#'     zoom_in_left(
+#'       h1("Hello world!")
+#'     )
+#'   )
+#'
+#'   server <- function(input, output, session) {}
+#'
+#'   shinyApp(ui, server)
+#' }
+#' @export
+zoom_in_left <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("zoom-in-left", duration, delay, steps, iteration)
+  htmltools::tagAppendAttributes(ui, class = x)
+}
+
+#' Zoom in right
+#'
+#' @description Animation to zoom a UI element right.
+#'
+#' @eval vov_params()
+#'
+#' @examples
+#' if (interactive()) {
+#'   library(shiny)
+#'   library(vov)
+#'
+#'   ui <- fluidPage(
+#'     use_vov(),
+#'     zoom_in_right(
+#'       h1("Hello world!")
+#'     )
+#'   )
+#'
+#'   server <- function(input, output, session) {}
+#'
+#'   shinyApp(ui, server)
+#' }
+#' @export
+zoom_in_right <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("zoom-in-right", duration, delay, steps, iteration)
+  htmltools::tagAppendAttributes(ui, class = x)
+}
+
+#' Zoom in up
+#'
+#' @description Animation to zoom a UI element up.
+#'
+#' @eval vov_params()
+#'
+#' @examples
+#' if (interactive()) {
+#'   library(shiny)
+#'   library(vov)
+#'
+#'   ui <- fluidPage(
+#'     use_vov(),
+#'     zoom_in_up(
+#'       h1("Hello world!")
+#'     )
+#'   )
+#'
+#'   server <- function(input, output, session) {}
+#'
+#'   shinyApp(ui, server)
+#' }
+#' @export
+zoom_in_up <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("zoom-in-up", duration, delay, steps, iteration)
+  htmltools::tagAppendAttributes(ui, class = x)
+}
+
+#' Zoom in
+#'
+#' @description Animation to zoom a UI element.
+#'
+#' @eval vov_params()
+#'
+#' @examples
+#' if (interactive()) {
+#'   library(shiny)
+#'   library(vov)
+#'
+#'   ui <- fluidPage(
+#'     use_vov(),
+#'     zoom_in(
+#'       h1("Hello world!")
+#'     )
+#'   )
+#'
+#'   server <- function(input, output, session) {}
+#'
+#'   shinyApp(ui, server)
+#' }
+#' @export
+zoom_in <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("zoom-in", duration, delay, steps, iteration)
+  htmltools::tagAppendAttributes(ui, class = x)
+}
+
+#' Zoom out down
+#'
+#' @description Animation to zoom a UI element down.
+#'
+#' @eval vov_params()
+#'
+#' @examples
+#' if (interactive()) {
+#'   library(shiny)
+#'   library(vov)
+#'
+#'   ui <- fluidPage(
+#'     use_vov(),
+#'     zoom_out_down(
+#'       h1("Hello world!")
+#'     )
+#'   )
+#'
+#'   server <- function(input, output, session) {}
+#'
+#'   shinyApp(ui, server)
+#' }
+#' @export
+zoom_out_down <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("zoom-out-down", duration, delay, steps, iteration)
+  htmltools::tagAppendAttributes(ui, class = x)
+}
+
+#' Zoom out left
+#'
+#' @description Animation to zoom a UI element left.
+#'
+#' @eval vov_params()
+#'
+#' @examples
+#' if (interactive()) {
+#'   library(shiny)
+#'   library(vov)
+#'
+#'   ui <- fluidPage(
+#'     use_vov(),
+#'     zoom_out_left(
+#'       h1("Hello world!")
+#'     )
+#'   )
+#'
+#'   server <- function(input, output, session) {}
+#'
+#'   shinyApp(ui, server)
+#' }
+#' @export
+zoom_out_left <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("zoom-out-left", duration, delay, steps, iteration)
+  htmltools::tagAppendAttributes(ui, class = x)
+}
+
+#' Zoom out right
+#'
+#' @description Animation to zoom a UI element right.
+#'
+#' @eval vov_params()
+#'
+#' @examples
+#' if (interactive()) {
+#'   library(shiny)
+#'   library(vov)
+#'
+#'   ui <- fluidPage(
+#'     use_vov(),
+#'     zoom_out_right(
+#'       h1("Hello world!")
+#'     )
+#'   )
+#'
+#'   server <- function(input, output, session) {}
+#'
+#'   shinyApp(ui, server)
+#' }
+#' @export
+zoom_out_right <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("zoom-out-right", duration, delay, steps, iteration)
+  htmltools::tagAppendAttributes(ui, class = x)
+}
+
+#' Zoom out up
+#'
+#' @description Animation to zoom a UI element up.
+#'
+#' @eval vov_params()
+#'
+#' @examples
+#' if (interactive()) {
+#'   library(shiny)
+#'   library(vov)
+#'
+#'   ui <- fluidPage(
+#'     use_vov(),
+#'     zoom_out_up(
+#'       h1("Hello world!")
+#'     )
+#'   )
+#'
+#'   server <- function(input, output, session) {}
+#'
+#'   shinyApp(ui, server)
+#' }
+#' @export
+zoom_out_up <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("zoom-out-up", duration, delay, steps, iteration)
+  htmltools::tagAppendAttributes(ui, class = x)
+}
+
+#' Zoom out
+#'
+#' @description Animation to zoom a UI element.
+#'
+#' @eval vov_params()
+#'
+#' @examples
+#' if (interactive()) {
+#'   library(shiny)
+#'   library(vov)
+#'
+#'   ui <- fluidPage(
+#'     use_vov(),
+#'     zoom_out(
+#'       h1("Hello world!")
+#'     )
+#'   )
+#'
+#'   server <- function(input, output, session) {}
+#'
+#'   shinyApp(ui, server)
+#' }
+#' @export
+zoom_out <- function(ui, duration = NULL, delay = NULL, steps = NULL, iteration = NULL) {
+  x <- parse_animation("zoom-out", duration, delay, steps, iteration)
+  htmltools::tagAppendAttributes(ui, class = x)
+}
